# pyTuplingUtils

[![build-status](https://app.travis-ci.com/umd-lhcb/pyTuplingUtils.svg?branch=master)](https://app.travis-ci.com/github/umd-lhcb/pyTuplingUtils)
[![coverage](https://codecov.io/gh/umd-lhcb/pyTuplingUtils/branch/master/graph/badge.svg)](https://codecov.io/gh/umd-lhcb/pyTuplingUtils)
[![PyPI version](https://shields.io/pypi/v/pyTuplingUtils)](https://pypi.org/project/pyTuplingUtils)

Utilities for ntuples, such as plotting and simple debugging, with the help of
`uproot`.
